|PyJibe|
========

|PyPI Version| |Tests Status| |Coverage Status| |Docs Status|


**PyJibe** is a graphical end-user software for the analysis of atomic force
microscopy data.


Documentation
-------------
The documentation, including the code reference and examples, is available at
`pyjibe.readthedocs.io <https://pyjibe.readthedocs.io/en/stable/>`__.


Installation
------------
You can find pre-built binaries on the `release page <https://github.com/AFM-analysis/PyJibe/releases/latest>`__.
If you have Python installed, you may also install via

::

    # install PyJibe
    pip install pyjibe
    # start PyJibe
    python -m pyjibe


.. |PyJibe| image:: https://raw.github.com/AFM-analysis/PyJibe/master/docs/logo/PyJibe.png
.. |PyPI Version| image:: https://img.shields.io/pypi/v/PyJibe.svg
   :target: https://pypi.python.org/pypi/PyJibe
.. |Tests Status| image:: https://img.shields.io/github/actions/workflow/status/AFM-analysis/PyJibe/check.yml
   :target: https://github.com/AFM-analysis/PyJibe/actions?query=workflow%3AChecks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/AFM-analysis/PyJibe/master.svg
   :target: https://codecov.io/gh/AFM-analysis/PyJibe
.. |Docs Status| image:: https://readthedocs.org/projects/pyjibe/badge/?version=latest
   :target: https://readthedocs.org/projects/pyjibe/builds/
